Type: Package
Package: explore
Title: Simplifies Exploratory Data Analysis
Version: 1.4.0
Authors@R: 
    person("Roland", "Krasser", , "roland.krasser@gmail.com", role = c("aut", "cre"))
Description: Interactive data exploration with one line of code, automated
    reporting or use an easy to remember set of tidy functions for low
    code exploratory data analysis.
License: MIT + file LICENSE
URL: https://rolkra.github.io/explore/,
        https://github.com/rolkra/explore
BugReports: https://github.com/rolkra/explore/issues
Depends: R (>= 3.5.0)
Imports: cli, dplyr (>= 1.1.0), DT (>= 0.3.0), forcats (>= 1.0.0),
        ggplot2 (>= 3.4.0), grDevices, gridExtra, magrittr,
        palmerpenguins, plotly, rlang (>= 1.1.0), rmarkdown, rpart,
        rpart.plot, shiny, stats, stringr, tibble
Suggests: knitr, MASS, randomForest, xgboost, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-12-10 08:18:55 UTC; ujqb7lf
Author: Roland Krasser [aut, cre]
Maintainer: Roland Krasser <roland.krasser@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-11 06:10:31 UTC
Built: R 4.6.0; ; 2026-04-30 09:51:33 UTC; unix
