# Generated by roxygen2: do not edit by hand

export(abtest)
export(add_var_id)
export(add_var_random_01)
export(add_var_random_cat)
export(add_var_random_dbl)
export(add_var_random_int)
export(add_var_random_moon)
export(add_var_random_starsign)
export(balance_target)
export(clean_var)
export(count_pct)
export(create_data_abtest)
export(create_data_app)
export(create_data_buy)
export(create_data_churn)
export(create_data_empty)
export(create_data_esoteric)
export(create_data_newsletter)
export(create_data_person)
export(create_data_random)
export(create_data_unfair)
export(create_notebook_explore)
export(data_dict_md)
export(decrypt)
export(describe)
export(describe_all)
export(describe_cat)
export(describe_num)
export(describe_tbl)
export(drop_obs_if)
export(drop_obs_with_na)
export(drop_var_by_names)
export(drop_var_low_variance)
export(drop_var_no_variance)
export(drop_var_not_numeric)
export(drop_var_with_na)
export(encrypt)
export(explain_forest)
export(explain_logreg)
export(explain_tree)
export(explain_xgboost)
export(explore)
export(explore_all)
export(explore_bar)
export(explore_col)
export(explore_cor)
export(explore_count)
export(explore_density)
export(explore_shiny)
export(explore_targetpct)
export(explore_tbl)
export(format_num_auto)
export(format_num_kMB)
export(format_num_space)
export(format_target)
export(format_type)
export(get_color)
export(get_nrow)
export(get_type)
export(get_var_buckets)
export(guess_cat_num)
export(interact)
export(mix_color)
export(plot_legend_targetpct)
export(plot_text)
export(predict_target)
export(replace_na_with)
export(report)
export(rescale01)
export(show_color)
export(simplify_text)
export(total_fig_height)
export(use_data_beer)
export(use_data_diamonds)
export(use_data_iris)
export(use_data_mpg)
export(use_data_mtcars)
export(use_data_penguins)
export(use_data_starwars)
export(use_data_titanic)
export(use_data_wordle)
export(weight_target)
export(yyyymm_calc)
import(dplyr)
import(ggplot2)
import(rlang)
importFrom(dplyr,mutate)
importFrom(forcats,fct_reorder)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,text)
importFrom(gridExtra,grid.arrange)
importFrom(magrittr,"%>%")
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,glm)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_trim)
importFrom(utils,browseURL)
importFrom(utils,head)
